@@ -2,7 +2,7 @@
  * Please see file COPYING or http://bitzi.com/publicdomain 
  * for more info.
  *
- * $Id: bitcollider.h,v 1.12 2001/10/12 21:37:52 mayhemchaos Exp $
+ * $Id: bitcollider.h,v 1.14 2003/10/27 03:09:35 gojomo Exp $
  */
 #ifndef BITCOLLIDER_H
 #define BITCOLLIDER_H
@@ -41,6 +41,8 @@ typedef struct _Bitcollider
     char       *error; 
     void      (*progressCallback)(int, const char *, const char *);
     b_bool      preview;
+    b_bool      calculateMD5;
+    b_bool      calculateCRC32;
     b_bool      exitNow;
 #if USE_BDB
     cache_info *cache;
@@ -82,6 +84,10 @@ void                  set_progress_callback(Bitcollider          *bc,
                                                                  const char *));
 void                   set_preview         (Bitcollider          *bc,
                                             b_bool                enable);
+void                   set_calculateMD5    (Bitcollider          *bc,
+                                            b_bool                enable);
+void                   set_calculateCRC32  (Bitcollider          *bc,
+                                            b_bool                enable);
 void                   set_exit            (Bitcollider          *bc,
                                             b_bool                enable);
 void                   clear_bitprint_cache(Bitcollider          *bc);
