@@ -1,8 +1,8 @@
-/* (PD) 2001 The Bitzi Corporation
- * Please see file COPYING or http://bitzi.com/publicdomain 
+/* (PD) 2004 The Bitzi Corporation
+ * Please see file COPYING or http://bitzi.com/publicdomain
  * for more info.
  *
- * $Id: main.c,v 1.41 2002/07/06 09:30:15 gojomo Exp $
+ * $Id: main.c,v 1.49 2004/02/03 02:47:34 gojomo Exp $
  */
 /*------------------------------------------------------------------------- */
 #include <stdio.h>
@@ -17,6 +17,7 @@
 #include "md5.h"
 #include "ed2k_md4.h"
 #include "ftuuhash.h"
+#include "kztree.h"
 #include "mp3.h"
 #include "id3.h"
 #include "plugin_man.h"
@@ -65,7 +66,8 @@
 
 b_bool calculate_hashes(BitcolliderSubmission *submission,
                         FILE                  *source,
-                        char                  *bitprint, 
+                        char                  *bitprint,
+						char                  *crc32,
                         char                  *md5sum,
 						char                  *ed2kmd4sum,
 						char                  *ftuusum,
@@ -73,15 +75,16 @@ b_bool calculate_hashes(BitcolliderSubmission *submission,
                         PluginMethods         *methods,
                         Attribute            **attrList);
 b_bool generate_first_n_hex(BitcolliderSubmission *submission,
-                            FILE          *source, 
-                            int            n, 
+                            FILE          *source,
+                            int            n,
                             unsigned char *bitprint);
 b_bool get_bitprint_data(BitcolliderSubmission *submission,
-                         const char            *fileName, 
-                         char                  *bitprint, 
+                         const char            *fileName,
+                         char                  *bitprint,
+						 char                  *crc32,
                          char                  *md5sum,
 						 char                  *ed2kmd4sum,
-						 char                  *ftuusum,
+						 char                  *kzhashhex,
                          unsigned char         *firstHex,
                          mp3_info              *mp3Info,
                          PluginMethods         *methods,
@@ -102,15 +105,15 @@ Bitcollider *bitcollider_init(b_bool printDebugInfo)
 #endif
     char         path[MAX_PATH], cacheFile[MAX_PATH], *ptr;
     int          total = 0;
-    
+
     cacheFile[0] = 0;
     bc = init_plugins();
 
 #ifndef WIN32
     /* Load the plugins from the build dir first if ./plugins exists */
     if (printDebugInfo)
-        fprintf(stderr, "Loading plugins from ./plugins:\n"); 
-        
+        fprintf(stderr, "Loading plugins from ./plugins:\n");
+
     total = load_plugins(bc, "./plugins", printDebugInfo);
 
     ptr = getenv("HOME");
@@ -119,20 +122,20 @@ Bitcollider *bitcollider_init(b_bool printDebugInfo)
         sprintf(cacheFile, "%s/.bitcollider/cache.db", ptr);
         sprintf(path, "%s/.bitcollider/plugins", ptr);
         if (printDebugInfo)
-            fprintf(stderr, "Loading plugins from %s:\n", path); 
+            fprintf(stderr, "Loading plugins from %s:\n", path);
         total += load_plugins(bc, path, printDebugInfo);
     }
     else
     {
         if (printDebugInfo)
-            fprintf(stderr, "HOME env var not set. Cannot find home.\n"); 
+            fprintf(stderr, "HOME env var not set. Cannot find home.\n");
     }
 
     ptr = PREFIX"/lib/bitcollider/plugins";
 #else
-    
+
     path[0] = 0;
-    if (RegOpenKeyEx(HKEY_LOCAL_MACHINE, "Software\\Bitzi", 0, 
+    if (RegOpenKeyEx(HKEY_LOCAL_MACHINE, "Software\\Bitzi", 0,
         KEY_READ, &hKey) != ERROR_SUCCESS)
     {
         /* No registry key set. Figure out where our plugin dir is and
@@ -146,7 +149,7 @@ Bitcollider *bitcollider_init(b_bool printDebugInfo)
         DWORD size = MAX_PATH;
 
         // Get the plugin dir, first
-        ret = RegQueryValueEx(hKey, "PluginDir", NULL, &type, 
+        ret = RegQueryValueEx(hKey, "PluginDir", NULL, &type,
                               path, &size);
 
         if (ret == ERROR_FILE_NOT_FOUND)
@@ -160,7 +163,7 @@ Bitcollider *bitcollider_init(b_bool printDebugInfo)
 
         // Now try to get the cache file
         size = MAX_PATH;
-        ret = RegQueryValueEx(hKey, "CacheFile", NULL, &type, 
+        ret = RegQueryValueEx(hKey, "CacheFile", NULL, &type,
                               cacheFile, &size);
         RegCloseKey(hKey);
     }
@@ -170,7 +173,7 @@ Bitcollider *bitcollider_init(b_bool printDebugInfo)
     if (ptr)
     {
         if (printDebugInfo)
-            fprintf(stderr, "Loading plugins from %s:\n", ptr); 
+            fprintf(stderr, "Loading plugins from %s:\n", ptr);
         total += load_plugins(bc, ptr, printDebugInfo);
     }
     if (printDebugInfo)
@@ -192,7 +195,7 @@ Bitcollider *bitcollider_init(b_bool printDebugInfo)
                 if (!create_cache(bc->cache, cacheFile, bc->maxCacheSize))
                 {
                     if (printDebugInfo)
-                        fprintf(stderr, "Failed to create cache file: %s.\n\n", 
+                        fprintf(stderr, "Failed to create cache file: %s.\n\n",
                                     cacheFile);
                     close_cache(bc->cache);
                     bc->cache = NULL;
@@ -201,7 +204,7 @@ Bitcollider *bitcollider_init(b_bool printDebugInfo)
         }
     }
 #endif
-    
+
     return bc;
 }
 
@@ -229,16 +232,17 @@ BitcolliderSubmission *create_submission(Bitcollider *bc)
     return submission;
 }
 
-b_bool analyze_file(BitcolliderSubmission *submission, 
+b_bool analyze_file(BitcolliderSubmission *submission,
                     const char            *fileName,
                     b_bool                 matchingExtsOnly)
 {
     char                   bitprint[BITPRINT_BASE32_LEN + 1];
     char                   firstNHex[FIRST_N_HEX_SIZE + 1];
     char                   temp[MAX_ATTR_STRING_LEN], *ext;
+	char                   crc32[10];
     char                   md5[64];
 	char                   ed2kmd4[64];
-	char                   ftuu[64];
+	char                   kzhashhex[128];
     const char            *baseFileName;
     mp3_info              *mp3Info = NULL;
     PluginMethods         *methods = NULL;
@@ -301,7 +305,7 @@ b_bool analyze_file(BitcolliderSubmission *submission,
     if (matchingExtsOnly && methods == NULL && mp3Check == false)
     {
        if (submission->bc->progressCallback && !submission->bc->preview)
-           submission->bc->progressCallback(0, submission->fileName, 
+           submission->bc->progressCallback(0, submission->fileName,
                                             "skipped.");
        return false;
     }
@@ -323,16 +327,16 @@ b_bool analyze_file(BitcolliderSubmission *submission,
         strcpy(centry.fileName, fileName);
 #endif
 
-    if (submission->bc->cache && 
+    if (submission->bc->cache &&
         get_cache_entry(submission->bc->cache, &centry))
     {
         if (_stat(submission->fileName, (struct _stat *)&fileInfo) == 0)
         {
             if (fileInfo.st_mtime == centry.lastModDate)
             {
-                if (submission->bc->progressCallback && 
+                if (submission->bc->progressCallback &&
                     !submission->bc->preview)
-                    submission->bc->progressCallback(0, submission->fileName, 
+                    submission->bc->progressCallback(0, submission->fileName,
                                    "found in cache, skipped.");
                 return true;
             }
@@ -346,7 +350,7 @@ b_bool analyze_file(BitcolliderSubmission *submission,
     if (mp3Check)
        mp3Info = malloc(sizeof(mp3_info));
 
-    if (!get_bitprint_data(submission, fileName, bitprint, md5, ed2kmd4, ftuu, firstNHex, 
+    if (!get_bitprint_data(submission, fileName, bitprint, crc32, md5, ed2kmd4, kzhashhex, firstNHex,
                            mp3Info, methods, &attrList))
     {
        if (mp3Info)
@@ -376,9 +380,18 @@ b_bool analyze_file(BitcolliderSubmission *submission,
     add_attribute(submission, "tag.file.length", temp);
     add_attribute(submission, "tag.file.first20", firstNHex);
     add_attribute(submission, "tag.filename.filename", baseFileName);
-    // add_attribute(submission, "tag.md5.md5", md5);
+
+    if (submission->bc->calculateCRC32)
+	{
+		add_attribute(submission, "tag.crc32.crc32", crc32);
+	}
+    if (submission->bc->calculateMD5)
+    {
+        add_attribute(submission, "tag.md5.md5", md5);
+    }
+
     add_attribute(submission, "tag.ed2k.ed2khash", ed2kmd4);
-	add_attribute(submission, "tag.uuhash.uuhash", ftuu);
+	add_attribute(submission, "tag.kzhash.kzhash", kzhashhex);
 
     /* Check to make sure that we carried out the mp3 check, and
        make sure that an audioSha was generated. If not, then the
@@ -411,7 +424,7 @@ b_bool analyze_file(BitcolliderSubmission *submission,
        }
        sprintf(temp, "%d", mp3Info->samplerate);
        add_attribute(submission, "tag.mp3.samplerate", temp);
-       add_attribute(submission, "tag.mp3.stereo", 
+       add_attribute(submission, "tag.mp3.stereo",
                                   mp3Info->stereo ? "y" : "n");
        add_attribute(submission, "tag.mp3.audio_sha1", audioShaDigest);
        free(mp3Info);
@@ -428,7 +441,7 @@ b_bool analyze_file(BitcolliderSubmission *submission,
            if (info->album)
                add_attribute(submission, "tag.audiotrack.album", info->album);
            if (info->tracknumber)
-               add_attribute(submission, "tag.audiotrack.tracknumber", 
+               add_attribute(submission, "tag.audiotrack.tracknumber",
                              info->tracknumber);
            if (info->genre && atoi(info->genre) >= 0)
                add_attribute(submission, "tag.id3genre.genre", info->genre);
@@ -462,8 +475,8 @@ b_bool analyze_file(BitcolliderSubmission *submission,
            set_warning(submission, err);
     }
 
-    if (submission->bc->progressCallback && 
-        !submission->bc->preview && 
+    if (submission->bc->progressCallback &&
+        !submission->bc->preview &&
         !submission->bc->exitNow)
        submission->bc->progressCallback(100, NULL, "ok.");
 
@@ -473,10 +486,10 @@ b_bool analyze_file(BitcolliderSubmission *submission,
     if (_stat(submission->fileName, (struct _stat *)&fileInfo) == 0)
     {
         centry.lastModDate = fileInfo.st_mtime;
-        if (submission->bc->cache && 
+        if (submission->bc->cache &&
             !add_cache_entry(submission->bc->cache, &centry, false))
         {
-            printf("Failed to insert bitprint into cache.\n");        
+            printf("Failed to insert bitprint into cache.\n");
         }
     }
 #endif
@@ -510,9 +523,19 @@ void set_preview(Bitcollider *bc, b_bool preview)
     bc->preview = preview;
 }
 
+void set_calculateCRC32(Bitcollider *bc, b_bool calculateCRC32)
+{
+    bc->calculateCRC32 = calculateCRC32;
+}
+
+void set_calculateMD5(Bitcollider *bc, b_bool calculateMD5)
+{
+    bc->calculateMD5 = calculateMD5;
+}
+
 void set_exit(Bitcollider *bc, b_bool exitNow)
 {
-    if (bc->progressCallback) 
+    if (bc->progressCallback)
        bc->progressCallback(-2, NULL, "operation cancelled.");
     bc->exitNow = exitNow;
 }
@@ -524,12 +547,12 @@ void clear_bitprint_cache(Bitcollider *bc)
     {
         int maxCount;
         char fileName[MAX_PATH];
-    
+
         strcpy(fileName, bc->cache->fileName);
         maxCount = get_max_count(bc->cache);
         close_cache(bc->cache);
         unlink(fileName);
-    
+
         bc->cache = init_cache();
         create_cache(bc->cache, fileName, maxCount);
     }
@@ -593,10 +616,10 @@ void convert_to_multiple_submission(BitcolliderSubmission *submission)
         if (strncmp("head.version", submission->attrList[i]->key, 12) == 0)
         {
             submission->attrList[i]->value[0] = 'M';
-            continue; 
+            continue;
         }
         if (strncmp("head.", submission->attrList[i]->key, 5) == 0)
-            continue; 
+            continue;
 
         temp = malloc(strlen(submission->attrList[i]->key) + 3);
         sprintf(temp, "0.%s", submission->attrList[i]->key);
@@ -605,8 +628,8 @@ void convert_to_multiple_submission(BitcolliderSubmission *submission)
     }
 }
 
-void convert_to_hex(const unsigned char *buffer, 
-                    int size, 
+void convert_to_hex(const unsigned char *buffer,
+                    int size,
                     char *hexBuffer)
 {
     int i;
@@ -618,7 +641,7 @@ void convert_to_hex(const unsigned char *buffer,
 }
 
 
-void add_attribute(BitcolliderSubmission *submission, 
+void add_attribute(BitcolliderSubmission *submission,
                    const char *key,
                    const char *value)
 {
@@ -628,7 +651,7 @@ void add_attribute(BitcolliderSubmission *submission,
     /* Check to see if the attr list already exists */
     if (submission->attrList == NULL)
     {
-        submission->attrList = (Attribute **)malloc(sizeof(Attribute *) * 
+        submission->attrList = (Attribute **)malloc(sizeof(Attribute *) *
                                                 DEFAULT_NUM_ATTRS);
         memset(submission->attrList, 0, sizeof(submission->attrList));
         submission->numItems = 0;
@@ -640,9 +663,9 @@ void add_attribute(BitcolliderSubmission *submission,
     {
         submission->numAllocated += GROW_NUM_ATTRS;
         submission->attrList = (Attribute **)realloc(submission->attrList,
-                                                 sizeof(Attribute *) * 
+                                                 sizeof(Attribute *) *
                                                  submission->numAllocated);
-        memset(&submission->attrList[submission->numItems], 
+        memset(&submission->attrList[submission->numItems],
                0, sizeof(Attribute *) * GROW_NUM_ATTRS);
     }
 
@@ -659,10 +682,10 @@ void add_attribute(BitcolliderSubmission *submission,
     for(i = 0; i < submission->numItems; i++)
     {
         if (strcmp(key, submission->attrList[i]->key) == 0)
-            return; 
+            return;
     }
 
-    submission->attrList[submission->numItems] = 
+    submission->attrList[submission->numItems] =
                 (Attribute *)malloc(sizeof(Attribute));
     submission->attrList[submission->numItems]->key = strdup(key);
     submission->attrList[submission->numItems]->value = strdup(value);
@@ -672,7 +695,7 @@ void add_attribute(BitcolliderSubmission *submission,
        free(temp);
 }
 
-const char *get_attribute(BitcolliderSubmission *submission, 
+const char *get_attribute(BitcolliderSubmission *submission,
                           const char *key)
 {
     int i;
@@ -687,15 +710,16 @@ const char *get_attribute(BitcolliderSubmission *submission,
 }
 
 b_bool get_bitprint_data(BitcolliderSubmission *submission,
-                         const char            *fileName, 
-                         char                  *bitprint, 
+                         const char            *fileName,
+                         char                  *bitprint,
+						 char                  *crc32hex,
                          char                  *md5sum,
 						 char                  *ed2kmd4,
-						 char                  *ftuu,
+						 char                  *kzhashhex,
                          unsigned char         *firstHex,
                          mp3_info              *mp3Info,
                          PluginMethods         *methods,
-                         Attribute            **attrList)     
+                         Attribute            **attrList)
 {
     FILE  *source;
     b_bool   ret;
@@ -711,7 +735,7 @@ b_bool get_bitprint_data(BitcolliderSubmission *submission,
     submission->fileSize = ftell(source);
     fseek(source, 0, SEEK_SET);
 
-    ret = calculate_hashes(submission, source, bitprint, md5sum, ed2kmd4, ftuu,
+    ret = calculate_hashes(submission, source, bitprint, crc32hex, md5sum, ed2kmd4, kzhashhex,
                            mp3Info, methods, attrList);
     if (ret)
         ret = generate_first_n_hex(submission, source, FIRST_N_HEX, firstHex);
@@ -722,19 +746,22 @@ b_bool get_bitprint_data(BitcolliderSubmission *submission,
 
 b_bool calculate_hashes(BitcolliderSubmission *submission,
                         FILE                  *source,
-                        char                  *bitprint, 
+                        char                  *bitprint,
+						char                  *crc32hex,
                         char                  *md5sum,
 						char                  *ed2kmd4sum,
-						char                  *ftuusum,
+						char                  *kzhashsum,
                         mp3_info              *mcontext,
                         PluginMethods         *methods,
-                        Attribute            **attrList)     
+                        Attribute            **attrList)
 {
     BP_CONTEXT         bcontext;
-    struct MD5Context  md5context; 
+    unsigned int       crc32 = 0xffffffff;
+    struct MD5Context  md5context;
 	ED2K_CTX           ed2kmd4context;
 	FTUU_CTX           ftuucontext;
-    unsigned char     *buffer, bitprintRaw[BITPRINT_RAW_LEN], md5Digest[16], ed2kDigest[16], ftuuDigest[20];
+	KZTREE_CONTEXT     kztreecontext;
+    unsigned char     *buffer, bitprintRaw[BITPRINT_RAW_LEN], md5Digest[16], ed2kDigest[16], kzhash[36];
     int                bytes;
     b_bool             ret = true;
     Context           *context = NULL;
@@ -749,9 +776,13 @@ b_bool calculate_hashes(BitcolliderSubmission *submission,
        mp3_init(mcontext);
     if (methods && methods->mem_analyze_init)
        context = methods->mem_analyze_init();
-    // MD5Init(&md5context);
-	ED2KInit(&ed2kmd4context);
-	FTUUInit(&ftuucontext);
+	if (submission->bc->calculateCRC32)
+		crc32 = 0xffffffff; //init
+    if (submission->bc->calculateMD5)
+        MD5Init(&md5context);
+    ED2KInit(&ed2kmd4context);
+    FTUUInit(&ftuucontext);
+	kztree_init(&kztreecontext);
 
     buffer = (unsigned char*)malloc(BUFFER_LEN);
     if (buffer == NULL)
@@ -759,7 +790,7 @@ b_bool calculate_hashes(BitcolliderSubmission *submission,
        set_error(submission, ERROR_MALLOCFAILED);
        return false;
     }
-   
+
     submission->percentComplete = 0;
     if (submission->bc->progressCallback && !submission->bc->preview)
         submission->bc->progressCallback(0, submission->fileName, NULL);
@@ -768,7 +799,7 @@ b_bool calculate_hashes(BitcolliderSubmission *submission,
     for(;;)
     {
         if (submission->bc->exitNow)
-           return false; 
+           return false;
 
         bytes = fread(buffer, 1, BUFFER_LEN, source);
         if (bytes <= 0)
@@ -782,15 +813,20 @@ b_bool calculate_hashes(BitcolliderSubmission *submission,
            mp3_update(mcontext, buffer, bytes);
         if (methods && methods->mem_analyze_update)
            methods->mem_analyze_update(context, buffer, bytes);
-        // MD5Update(&md5context, buffer, bytes);
-		ED2KUpdate(&ed2kmd4context, buffer, bytes);
-		FTUUUpdate(&ftuucontext, buffer, bytes);
-        
+
+        if (submission->bc->calculateCRC32)
+            crc32 = hashSmallHash(buffer, bytes , crc32); //crc32 by another name
+        if (submission->bc->calculateMD5)
+            MD5Update(&md5context, buffer, bytes);
+        ED2KUpdate(&ed2kmd4context, buffer, bytes);
+        FTUUUpdate(&ftuucontext, buffer, bytes);
+		kztree_update(&kztreecontext, buffer, bytes);
+
         if (submission->bc->progressCallback && !submission->bc->preview)
         {
            int          percentComplete;
 
-           percentComplete = (int)(((word64)ftell(source) * (word64)100) / 
+           percentComplete = (int)(((word64)ftell(source) * (word64)100) /
                                     (word64)submission->fileSize);
            if (percentComplete != submission->percentComplete)
            {
@@ -811,32 +847,51 @@ b_bool calculate_hashes(BitcolliderSubmission *submission,
     if (methods && methods->mem_analyze_final)
         *attrList = methods->mem_analyze_final(context);
 
-    // MD5Final(md5Digest, &md5context);
-	ED2KFinal(ed2kDigest, &ed2kmd4context);
-	FTUUFinal(ftuuDigest, &ftuucontext);
+    if (submission->bc->calculateCRC32)
+    {
+        crc32=~crc32;
+        sprintf(crc32hex,"%08X", crc32);
+    }
 
-    bitziEncodeBase32(md5Digest, 16, md5sum);
-    sprintf(ed2kmd4sum,"%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x", 
+    if (submission->bc->calculateMD5)
+    {
+        MD5Final(md5Digest, &md5context);
+        //bitziEncodeBase32(md5Digest, 16, md5sum);
+		sprintf(md5sum,"%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
+		    md5Digest[0],md5Digest[1],md5Digest[2],md5Digest[3],
+			md5Digest[4],md5Digest[5],md5Digest[6],md5Digest[7],
+			md5Digest[8],md5Digest[9],md5Digest[10],md5Digest[11],
+			md5Digest[12],md5Digest[13],md5Digest[14],md5Digest[15]);
+    }
+
+    ED2KFinal(ed2kDigest, &ed2kmd4context);
+    FTUUFinal(kzhash, &ftuucontext);
+	kztree_digest(&kztreecontext,kzhash+20);
+
+    sprintf(ed2kmd4sum,"%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
 		    ed2kDigest[0],ed2kDigest[1],ed2kDigest[2],ed2kDigest[3],
 			ed2kDigest[4],ed2kDigest[5],ed2kDigest[6],ed2kDigest[7],
 			ed2kDigest[8],ed2kDigest[9],ed2kDigest[10],ed2kDigest[11],
 			ed2kDigest[12],ed2kDigest[13],ed2kDigest[14],ed2kDigest[15]);
-    /**
-	sprintf(ftuusum,"%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x", 
-		    ftuuDigest[0],ftuuDigest[1],ftuuDigest[2],ftuuDigest[3],
-			ftuuDigest[4],ftuuDigest[5],ftuuDigest[6],ftuuDigest[7],
-			ftuuDigest[8],ftuuDigest[9],ftuuDigest[10],ftuuDigest[11],
-			ftuuDigest[12],ftuuDigest[13],ftuuDigest[14],ftuuDigest[15],
-			ftuuDigest[16],ftuuDigest[17],ftuuDigest[18],ftuuDigest[19]);
-	**/
-	bitziEncodeBase64(ftuuDigest,20,ftuusum);
+
+	//bitziEncodeBase64(ftuuDigest,20,ftuusum);
+	sprintf(kzhashsum,"%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
+		    kzhash[0],kzhash[1],kzhash[2],kzhash[3],
+			kzhash[4],kzhash[5],kzhash[6],kzhash[7],
+			kzhash[8],kzhash[9],kzhash[10],kzhash[11],
+			kzhash[12],kzhash[13],kzhash[14],kzhash[15],
+			kzhash[16],kzhash[17],kzhash[18],kzhash[19],
+			kzhash[20],kzhash[21],kzhash[22],kzhash[23],
+			kzhash[24],kzhash[25],kzhash[26],kzhash[27],
+			kzhash[28],kzhash[29],kzhash[30],kzhash[31],
+			kzhash[32],kzhash[33],kzhash[34],kzhash[35]);
 
     return ret;
 }
 
 b_bool generate_first_n_hex(BitcolliderSubmission *submission,
-                            FILE                  *source, 
-                            int                    n, 
+                            FILE                  *source,
+                            int                    n,
                             unsigned char         *bits)
 {
     unsigned char *buffer;
@@ -847,7 +902,7 @@ b_bool generate_first_n_hex(BitcolliderSubmission *submission,
        set_error(submission, ERROR_MALLOCFAILED);
        return false;
     }
-   
+
     fseek(source, 0, SEEK_SET);
     n = fread(buffer, sizeof(unsigned char), n, source);
     if (n < 0)
@@ -864,8 +919,8 @@ b_bool generate_first_n_hex(BitcolliderSubmission *submission,
     return true;
 }
 
-b_bool submit_submission(BitcolliderSubmission *submission, 
-                         const char *url, 
+b_bool submit_submission(BitcolliderSubmission *submission,
+                         const char *url,
                          BrowserEnum browser)
 {
     FILE *output;
@@ -892,7 +947,7 @@ b_bool submit_submission(BitcolliderSubmission *submission,
        return false;
     }
 
-    fprintf(output, 
+    fprintf(output,
        "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\">\n");
     fprintf(output, "<HTML><HEAD><TITLE>");
 
@@ -907,13 +962,13 @@ b_bool submit_submission(BitcolliderSubmission *submission,
        fprintf(output, "<BODY>\n");
 
     if (submission->numBitprints == 1)
-       fprintf(output, "<h3>Bitprint Submission %s</h3><p>\n", 
+       fprintf(output, "<h3>Bitprint Submission %s</h3><p>\n",
                         submission->fileName);
     else
-       fprintf(output, "<h3>Multiple [%d] Bitprint Submission</h3><p>\n", 
+       fprintf(output, "<h3>Multiple [%d] Bitprint Submission</h3><p>\n",
                         submission->numBitprints);
 
-    fprintf(output, 
+    fprintf(output,
       "You are submitting the following bitprint and tag data to the web "
       "location <i>%s</i>. For more information see <a "
       "href=\"http://bitzi.com/bitcollider/websubmit\">the Bitzi website.</a>"
@@ -923,10 +978,10 @@ b_bool submit_submission(BitcolliderSubmission *submission,
       "may press the \"submit\" button which will appear at the bottom of "
       "the page.<p><HR>\n", (url == NULL) ? SUBMIT_URL : url);
 
-    fprintf(output, "<FORM method=post action=\"%s\">\n", 
+    fprintf(output, "<FORM method=post action=\"%s\">\n",
                      (url == NULL) ? SUBMIT_URL : url);
     fprintf(output, "<PRE>\n");
-   
+
     for(i = 0; i < submission->numItems; i++)
     {
         if (last != atoi(submission->attrList[i]->key) || i == 2)
@@ -1037,7 +1092,7 @@ BitcolliderSubmission *read_submission_from_file(Bitcollider *bc, char *fileName
     int                    line, empty = 1;
     FILE                  *infile;
 
-    if (strcmp(fileName, "-"))
+    if (!strcmp(fileName, "-"))
        infile = stdin;
     else
        infile = fopen(fileName, "rb");
@@ -1086,7 +1141,7 @@ BitcolliderSubmission *read_submission_from_file(Bitcollider *bc, char *fileName
        for( c = buf; *c == ' ' && *c == '\t'; ++c )
            ; /* <-- Empty for loop */
 
-       if( ! *c || *c == '#' ) 
+       if( ! *c || *c == '#' )
            continue;
 
        if( ! ( t = strchr( c, '=' ) ) )
@@ -1098,7 +1153,7 @@ BitcolliderSubmission *read_submission_from_file(Bitcollider *bc, char *fileName
            return submission;
        }
        *t = 0;
-       if( ! strncmp( c, "head.", 5 ) ) 
+       if( ! strncmp( c, "head.", 5 ) )
            continue;
        if( isdigit( *c ) )
        {
@@ -1120,7 +1175,7 @@ BitcolliderSubmission *read_submission_from_file(Bitcollider *bc, char *fileName
            empty = 0;
            get_agent_string(temp);
            add_attribute(submission, "head.agent", temp);
- 
+
            sprintf(temp, "S%s", BC_SUBMITSPECVER);
            add_attribute(submission, "head.version", temp);
        }
@@ -1148,7 +1203,7 @@ void print_submission(BitcolliderSubmission *submission)
 
     for(i = 0; i < submission->numItems; i++)
     {
-        printf("%s=%s\n", 
+        printf("%s=%s\n",
                 submission->attrList[i]->key,
                 submission->attrList[i]->value);
     }
@@ -1156,12 +1211,12 @@ void print_submission(BitcolliderSubmission *submission)
 
 void get_agent_string(char *agentString)
 {
-    sprintf(agentString, "%s/%s (%s)", BC_AGENTNAME, BC_VERSION, 
+    sprintf(agentString, "%s/%s (%s)", BC_AGENTNAME, BC_VERSION,
                                        BC_AGENTBUILD);
 }
 
 #ifdef _WIN32
-/* We get to write this function becuase win95 does not 
+/* We get to write this function becuase win95 does not
    support this function! Thanks uncle Bill!!
 */
 void getLongPathName(const char *shortName, int len, char *longName)
@@ -1179,7 +1234,7 @@ void getLongPathName(const char *shortName, int len, char *longName)
     }
     else
     {   /* Hmmm. I guess we're screwed. */
-        strncpy(longName, shortName, len);         
+        strncpy(longName, shortName, len);
     }
     longName[len - 1] = 0;
 }
@@ -1187,7 +1242,7 @@ void getLongPathName(const char *shortName, int len, char *longName)
 
 b_bool check_md5_hash(void)
 {
-    struct MD5Context  md5context; 
+    struct MD5Context  md5context;
     unsigned char      md5Digest[16];
     char               md5Hash[33];
 
