@@ -2,7 +2,7 @@
  * Please see file COPYING or http://bitzi.com/publicdomain 
  * for more info.
  *
- * $Id: mp3.h,v 1.3 2001/05/18 01:00:54 mayhemchaos Exp $
+ * $Id: mp3.h,v 1.4 2001/07/31 18:49:20 mayhemchaos Exp $
  */
 #ifndef MP3_H
 #define MP3_H
@@ -28,6 +28,8 @@ typedef struct _mp3_info
     unsigned int   goodBytes, badBytes;
     unsigned char *startBuffer;
     unsigned int   startBytes;
+    unsigned char *audioShaBuffer, audioShaExtra[3];
+    unsigned int   audioShaBytes;
 } mp3_info;
 
 #define MP3_HEADER_SIZE 4
