@@ -2,7 +2,7 @@
  * Please see file COPYING or http://bitzi.com/publicdomain 
  * for more info.
  *
- * $Id: plugin_man.c,v 1.15 2001/09/10 23:52:47 mayhemchaos Exp $
+ * $Id: plugin_man.c,v 1.16 2004/02/03 01:11:07 mayhemchaos Exp $
  */
 /*------------------------------------------------------------------------- */
 #include <stdio.h>
@@ -55,7 +55,7 @@ int load_plugins(Bitcollider *bc, const char *path, b_bool printDebugInfo)
    DIR           *dir;
    struct dirent *entry;
    int            count = 0, j;
-   char          *ptr, file[MAX_PATH];
+   char          *ptr, file[MAX_PATH], init_func[255];
    PluginMethods *(*init_function)(void);
 
    dir = opendir(path);
@@ -87,15 +87,19 @@ int load_plugins(Bitcollider *bc, const char *path, b_bool printDebugInfo)
            continue;
        }
        bc->plugins[bc->numPluginsLoaded].file = strdup(entry->d_name);
+       strcpy(init_func, entry->d_name);
+       ptr = strrchr(init_func, '.');
+       if (ptr)
+           *ptr = 0;
+       strcat(init_func, "_init_plugin");
 
        /* Opened plugin ok, now locate our entry function */
-       init_function = lt_dlsym(bc->plugins[bc->numPluginsLoaded].handle, 
-                             "init_plugin");
+       init_function = lt_dlsym(bc->plugins[bc->numPluginsLoaded].handle, init_func);
        if (init_function == NULL)
        {
-           lt_dlclose(bc->plugins[bc->numPluginsLoaded].handle);
            if (printDebugInfo)
-               fprintf(stderr, "Cannot find entry point in %s.\n", file);
+               fprintf(stderr, "Cannot find entry point in %s (%s).\n", file, lt_dlerror());
+           lt_dlclose(bc->plugins[bc->numPluginsLoaded].handle);
            continue;
        }
 
