@@ -4,7 +4,7 @@
  *
  * Created and released into the public domain by Eli Biham
  *
- * $Id: tiger.c,v 1.3 2001/09/10 21:04:40 mayhemchaos Exp $
+ * $Id: tiger.c,v 1.4 2004/02/01 06:19:31 gojomo Exp $
  */
 #include "tiger.h"
 
@@ -86,7 +86,7 @@ extern word64 table[4*256];
       round(b,c,a,x7,mul)
 
 #define key_schedule \
-      x0 -= x7 ^ 0xA5A5A5A5A5A5A5A5; \
+      x0 -= x7 ^ 0xA5A5A5A5A5A5A5A5ULL; \
       x1 ^= x0; \
       x2 += x1; \
       x3 -= x2 ^ ((~x1)<<19); \
@@ -101,7 +101,7 @@ extern word64 table[4*256];
       x4 -= x3 ^ ((~x2)>>23); \
       x5 ^= x4; \
       x6 += x5; \
-      x7 -= x6 ^ 0x0123456789ABCDEF;
+      x7 -= x6 ^ 0x0123456789ABCDEFULL;
 
 #define feedforward \
       a ^= aa; \
@@ -174,9 +174,9 @@ void tiger(word64 *str, word64 length, word64 res[3])
   register word64 i, j;
   unsigned char temp[64];
 
-  res[0]=0x0123456789ABCDEF;
-  res[1]=0xFEDCBA9876543210;
-  res[2]=0xF096A5B4C3B2E187;
+  res[0]=0x0123456789ABCDEFULL;
+  res[1]=0xFEDCBA9876543210ULL;
+  res[2]=0xF096A5B4C3B2E187ULL;
 
   for(i=length; i>=64; i-=64)
     {
