@@ -17,7 +17,7 @@
  *
  *    http://www.cs.technion.ac.il/~biham/Reports/Tiger/
  *
- * $Id: tigertree.c,v 1.6 2001/09/10 21:13:18 mayhemchaos Exp $
+ * $Id: tigertree.c,v 1.7 2003/02/24 10:58:36 gojomo Exp $
  *
  */
 
@@ -41,13 +41,17 @@ void tt_endian(byte *s);
 void tt_init(TT_CONTEXT *ctx)
 {
   ctx->count = 0;
-  ctx->index = 0;
+  ctx->leaf[0] = 0; // flag for leaf  calculation -- never changed
+  ctx->node[0] = 1; // flag for inner node calculation -- never changed
+  ctx->block = ctx->leaf + 1 ; // working area for blocks
+  ctx->index = 0;   // partial block pointer/block length
   ctx->top = ctx->nodes;
 }
 
 static void tt_compose(TT_CONTEXT *ctx) {
   byte *node = ctx->top - NODESIZE;
-  tiger((word64*)node,(word64)NODESIZE,(word64*)ctx->top); // combine two nodes
+  memmove((ctx->node)+1,node,NODESIZE); // copy to scratch area
+  tiger((word64*)(ctx->node),(word64)(NODESIZE+1),(word64*)(ctx->top)); // combine two nodes
 #if USE_BIG_ENDIAN
   tt_endian((byte *)ctx->top);
 #endif
@@ -55,11 +59,11 @@ static void tt_compose(TT_CONTEXT *ctx) {
   ctx->top -= TIGERSIZE;                      // update top ptr
 }
 
-static void tt_block(TT_CONTEXT *ctx, byte *block)
+static void tt_block(TT_CONTEXT *ctx)
 {
   word64 b;
 
-  tiger((word64*)block,(word64)ctx->index,(word64*)ctx->top);
+  tiger((word64*)ctx->leaf,(word64)ctx->index+1,(word64*)ctx->top);
 #if USE_BIG_ENDIAN
   tt_endian((byte *)ctx->top);
 #endif
@@ -74,43 +78,48 @@ static void tt_block(TT_CONTEXT *ctx, byte *block)
 
 void tt_update(TT_CONTEXT *ctx, byte *buffer, word32 len)
 {
+
   if (ctx->index)
-    { /* Try to fill partial block */
-      unsigned left = BLOCKSIZE - ctx->index;
-      if (len < left)
-	{
-	  memmove(ctx->block + ctx->index, buffer, len);
-	  ctx->index += len;
-	  return; /* Finished */
-	}
-      else
-	{
-	  memmove(ctx->block + ctx->index, buffer, left);
-	  ctx->index = BLOCKSIZE;
-	  tt_block(ctx, ctx->block);
-	  buffer += left;
-	  len -= left;
-	}
-    }
+  { /* Try to fill partial block */
+	  unsigned left = BLOCKSIZE - ctx->index;
+	  if (len < left)
+		{
+		memmove(ctx->block + ctx->index, buffer, len);
+		ctx->index += len;
+		return; /* Finished */
+		}
+	  else
+		{
+		memmove(ctx->block + ctx->index, buffer, left);
+		ctx->index = BLOCKSIZE;
+		tt_block(ctx);
+		buffer += left;
+		len -= left;
+		}
+  }
+
   while (len >= BLOCKSIZE)
-    {
-      ctx->index = BLOCKSIZE;
-      tt_block(ctx, buffer);
-      buffer += BLOCKSIZE;
-      len -= BLOCKSIZE;
-    }
+	{
+	memmove(ctx->block, buffer, BLOCKSIZE);
+	ctx->index = BLOCKSIZE;
+	tt_block(ctx);
+	buffer += BLOCKSIZE;
+	len -= BLOCKSIZE;
+	}
   if ((ctx->index = len))     /* This assignment is intended */
-    /* Buffer leftovers */
-    memmove(ctx->block, buffer, len);
+	{
+	/* Buffer leftovers */
+	memmove(ctx->block, buffer, len);
+	}
 }
 
 // no need to call this directly; tt_digest calls it for you
 static void tt_final(TT_CONTEXT *ctx)
 {
-  // do last partial block, unless index is zero
+  // do last partial block, unless index is 1 (empty leaf)
   // AND we're past the first block
   if((ctx->index>0)||(ctx->top==ctx->nodes))
-    tt_block(ctx,ctx->block);
+    tt_block(ctx);
 }
 
 void tt_digest(TT_CONTEXT *ctx, byte *s)
