@@ -2,7 +2,7 @@
  * Please see file COPYING or http://bitzi.com/publicdomain 
  * for more info.
  *
- * $Id: bitcollider.c,v 1.18 2001/10/12 22:01:15 mayhemchaos Exp $
+ * $Id: bitcollider.c,v 1.23 2004/02/02 01:11:53 mayhemchaos Exp $
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -33,22 +33,20 @@ void usage()
    printf("Options:\n");
    printf(" -p        - print the submission info, without submitting\n");
    printf(" -n        - show submission in browser, without submitting\n");
-   printf(" -u        - send submission to alternate URL\n");
-   printf(" -3        - force mp3 analysis even if file does not end in .mp3\n");
+   printf(" -u [url]  - send submission to alternate URL\n");
    printf(" -e [ext]  - treat file as if it had a given extension\n");
    printf(" -d        - debug print during plugin loading\n");
    printf(" -r        - recurse into directories.\n");
    printf(" -a        - analyze all files for a given directory.\n");
    printf("             (Default is to analyze only known extensions)\n");
    printf(" -f <file> - read tags from <file> instead of analyzing\n");
-#ifdef USE_BDB
-   printf(" -c        - clear the bitprint cache\n");
-#endif
-#ifndef _WIN32
-   printf(" -k        - use the Konqueror to submit\n");
-   printf(" -m        - use the Mozilla to submit\n");
-   printf(" -o        - use the Opera to submit\n");
-   printf(" -l        - use the lynx to submit\n");
+   printf(" --md5      - calculate MD5\n");
+   printf(" --crc32    - calculate CRC32\n");
+#if !defined(_WIN32) && !defined(DARWIN)
+   printf(" --konqueror   - use the Konqueror browser to submit\n");
+   printf(" --lynx        - use the lynx browser to submit\n");
+   printf(" --mozilla     - use the Mozilla browser to submit\n");
+   printf(" --opera       - use the Opera browser to submit\n");
    printf("\nBy default Netscape will be used. You may also set the\n");
    printf("BROWSER environment variable to specify your browser of choice.\n");
    printf("Check http://www.tuxedo.org/~esr/BROWSER/index.html for details.\n");
@@ -139,6 +137,8 @@ int main(int argc, char *argv[])
   b_bool                 recurse = false;
   b_bool                 quiet = false;
   b_bool                 clearCache = false;
+  b_bool                 calculateMD5 = false;
+  b_bool                 calculateCRC32 = false;
   b_bool                 ret;
   char                   fileName[MAX_PATH];
 
@@ -158,22 +158,22 @@ int main(int argc, char *argv[])
   for(; argIndex < argc; argIndex++)
   {
 #ifndef _WIN32
-      if (strcmp(argv[argIndex], "-m") == 0)
+      if (strcmp(argv[argIndex], "--mozilla") == 0)
       {
           browser = eBrowserMozilla;
       }
       else
-      if (strcmp(argv[argIndex], "-k") == 0)
+      if (strcmp(argv[argIndex], "--konqueror") == 0)
       {
           browser = eBrowserKonqueror;
       }
       else
-      if (strcmp(argv[argIndex], "-o") == 0)
+      if (strcmp(argv[argIndex], "--opera") == 0)
       {
           browser = eBrowserOpera;
       }
       else
-      if (strcmp(argv[argIndex], "-l") == 0)
+      if (strcmp(argv[argIndex], "--lynx") == 0)
       {
           browser = eBrowserLynx;
       }
@@ -224,6 +224,16 @@ int main(int argc, char *argv[])
           clearCache = true;
       }
       else
+      if (strcmp(argv[argIndex], "--md5") == 0)
+      {
+          calculateMD5 = true;
+      }
+      else
+      if (strcmp(argv[argIndex], "--crc32") == 0)
+      {
+          calculateCRC32 = true;
+      }
+      else
       if (strcmp(argv[argIndex], "-e") == 0)
       {
           argIndex++;
@@ -232,17 +242,6 @@ int main(int argc, char *argv[])
           else
               strcpy(checkAsExt, argv[argIndex]);
       }
-      else
-      if (strcmp(argv[argIndex], "-3") == 0)
-      {
-          if (checkAsExt[0])
-          { 
-              fprintf(stderr, "You cannot use -3 and -e at the same time.");
-              fprintf(stderr, " -3 ignored.\n");
-          }
-          else
-              strcpy(checkAsExt, ".mp3");
-      }
       else
           break;
   }
@@ -254,13 +253,15 @@ int main(int argc, char *argv[])
 
   if (submitTarget)
   {
-      if (strncmp(submitTarget, "http://", 7))
+      if (!strncmp(submitTarget, "http://", 7) || !strncmp(submitTarget, "https://", 8))
+      {
+          fprintf(stderr, "Submitting to: %s\n\n", submitTarget);
+      }
+      else
       {
           fprintf(stderr, "'%s' is not a valid URL. Ignoring.\n\n", submitTarget);
           submitTarget = NULL;
       }
-      else
-          fprintf(stderr, "Submitting to: %s\n\n", submitTarget);
   }
 
   /* set the cleanup handler */
@@ -274,6 +275,9 @@ int main(int argc, char *argv[])
       exit(-1);
   }
 
+  set_calculateMD5(bc, calculateMD5);
+  set_calculateCRC32(bc, calculateCRC32);
+
   if (clearCache)
   {
       clear_bitprint_cache(bc);
@@ -342,16 +346,14 @@ int main(int argc, char *argv[])
              fprintf(stderr, "Cannot find file/dir %s. Skipping.\n", fileName);
              continue;
          }
-  
+
          if (type == eFile)
          {
              ret = analyze_file(submission, fileName, false);
              if (!ret)
              {
-                 print_error(bc, "Cannot analyze file");
-                 bitcollider_shutdown(bc);
-                 bc = NULL;
-                 exit(-1);
+                 fprintf(stderr, "%s problem: %s\n", fileName, get_error(bc));
+		 continue;
              }
          }
          else
