@@ -2,13 +2,19 @@
  * Please see file COPYING or http://bitzi.com/publicdomain 
  * for more info.
  *
- * $Id: wav.c,v 1.9 2001/06/18 07:27:17 mayhemchaos Exp $
+ * $Id: wav.c,v 1.10 2004/02/03 01:11:07 mayhemchaos Exp $
  */
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <assert.h>
 #include <errno.h>
+#ifdef WIN32
+#include <winsock.h>
+#else
+#include <netinet/in.h>
+#include <sys/param.h>
+#endif
 
 #include "plugin.h"
 #include "sha1.h"
@@ -16,6 +22,10 @@
 
 /*-------------------------------------------------------------------------*/
 
+#ifndef _WIN32
+#define init_plugin wav_init_plugin
+#endif
+
 PluginMethods           *init_plugin(void);
 static void              wav_shutdown_plugin(void);
 static void              wav_free_attributes(Attribute *attrList);
@@ -29,6 +39,9 @@ static void              wav_analyze_update(Context             *context,
 static Attribute        *wav_analyze_final(Context *context);
 static char             *wav_get_error(void);
 
+static long toLittleEndian32(long in);
+static short toLittleEndian16(short in);
+
 /*-------------------------------------------------------------------------*/
 
 #define CHUNK          4096
@@ -157,6 +170,21 @@ static void wav_analyze_update(Context             *contextArg,
         context->sampleSize = *((int16 *)&buf[34]); 
         context->dataLen = *((int32 *)&buf[40]); 
 
+#if WORDS_BIGENDIAN
+        context->channels = toLittleEndian16(context->channels);
+        context->sampleSize = toLittleEndian16(context->sampleSize);
+        context->sampleRate = toLittleEndian32(context->sampleRate);
+        context->dataLen = toLittleEndian32(context->dataLen);
+#endif
+
+        /*
+        printf(" samplesize: %d\n", context->sampleSize);
+        printf("sample rate: %d\n", context->sampleRate);
+        printf("   channels: %d\n", context->channels);
+        printf("    datalen: %d\n", context->dataLen);
+        printf("    samples: %u\n", context->samples);
+        */
+
         if (context->sampleSize != 8 && context->sampleSize != 16)
         {
            context->bytesProcessed = -1;
@@ -167,13 +195,6 @@ static void wav_analyze_update(Context             *contextArg,
         context->samples = context->dataLen / 
                            (context->channels * (context->sampleSize >> 3));
        
-        /*
-        printf("sample rate: %d\n", context->sampleRate);
-        printf("   channels: %d\n", context->channels);
-        printf(" samplesize: %d\n", context->sampleSize);
-        printf("    datalen: %d\n", context->dataLen);
-        printf("    samples: %u\n", context->samples);
-        */
 
         sha_update(&context->audioSha1, (unsigned char *)buf + 44, bufLen - 44);
         context->bytesProcessed += bufLen - 44;
@@ -249,3 +270,16 @@ static char *wav_get_error(void)
     return errorString;
 }
 
+static short toLittleEndian16(short in)
+{
+    char *ptr = (char *)&in;
+
+    return ((ptr[1] & 0xFF) << 8) | (ptr[0] & 0xFF); 
+}
+
+static long toLittleEndian32(long in)
+{
+    char *ptr = (char *)&in;
+
+    return ((ptr[3] & 0xFF) << 24) | ((ptr[2] & 0xFF) << 16) | ((ptr[1] & 0xFF) << 8) | (ptr[0] & 0xFF); 
+}
